<?php
/**
 * @package Dotclear
 *
 * @copyright Olivier Meunier & Association Dotclear
 * @copyright AGPL-3.0
 */

use Dotclear\Helper\File\Path;

if (!defined('DC_RC_PATH')) {
  return;
}

// Database driver (mysql (deprecated, disabled in PHP7), mysqli, mysqlimb4 (full UTF-8), pgsql, sqlite)
define('DC_DBDRIVER','mysqli');

// Database hostname (usually "localhost")
define('DC_DBHOST','[[softdbhost]]');

// Database user
define('DC_DBUSER','[[softdbuser]]');

// Database password
define('DC_DBPASSWORD','[[softdbpass]]');

// Database name
define('DC_DBNAME','[[softdb]]');

// Tables' prefix
define('DC_DBPREFIX','[[dbprefix]]');

// Persistent database connection
define('DC_DBPERSIST', false);

// Crypt key (password storage)
define('DC_MASTER_KEY','[[secret]]');

// Admin URL. You need to set it for some features.
define('DC_ADMIN_URL','[[softurl]]/admin/');

// Admin mail from address. For password recovery and such.
define('DC_ADMIN_MAILFROM','[[admin_email]]');

// Cookie's name
define('DC_SESSION_NAME', 'dcxd');

// Session TTL
//define('DC_SESSION_TTL','-20 hours');

// Plugins root
define('DC_PLUGINS_ROOT','[[softpath]]/plugins');

// Template cache directory
define('DC_TPL_CACHE','[[softpath]]/cache');

// Var directory
define('DC_VAR','[[softpath]]/var');

// Cryptographic algorithm
define('DC_CRYPT_ALGO', 'sha512');

// Vendor name
//define('DC_VENDOR_NAME', 'Dotclear');

// Do not check for update
//define('DC_NOT_UPDATE', false);

// Update URL
//define('DC_UPDATE_URL','https://download.dotclear.org/versions.xml');

// Update channel (stable, unstable, testing)
//define('DC_UPDATE_VERSION', 'stable');

// Proxy config
//define('HTTP_PROXY_HOST','127.0.0.1');
//define('HTTP_PROXY_PORT','8080');
//define('DC_REVERSE_PROXY',true);

// Show hidden media dirs
//define('DC_SHOW_HIDDEN_DIRS', false);

// Store update checking
//define('DC_STORE_NOT_UPDATE', false);

// Disable REST services (may be useful during debugging session)
//define('DC_REST_SERVICES', false);

// Load Legacy JS library
//define('DC_MIGRATE', false);

// If you have PATH_INFO issue, uncomment following lines
//if (!isset($_SERVER['ORIG_PATH_INFO'])) {
//    $_SERVER['ORIG_PATH_INFO'] = '';
//}
//$_SERVER['PATH_INFO'] = $_SERVER['ORIG_PATH_INFO'];

// If you have mail problems, uncomment following lines and adapt it to your hosting configuration
//function _mail($to, $subject, $message, $headers)
//{
//    \Dotclear\Helper\Network\Mail\MailSocket::$smtp_relay = 'my.smtp.relay.org';
//    \Dotclear\Helper\Network\Mail\MailSocket::mail($to, $subject, $message, $headers);
//}
